@@ -77,7 +77,9 @@ def create_project_configuration(filename):
     config = {'root': project_root_folder,
               'nntoolkit': None,
               'dropbox_app_key': None,
-              'dropbox_app_secret': None}
+              'dropbox_app_secret': None,
+              'dbconfig': os.path.join(home, "hwrt-config/db.config.yml"),
+              'data_analyzation_queue': [{'Creator': None}]}
     with open(filename, 'w') as f:
         yaml.dump(config, f, default_flow_style=False)
 
